<html>
<head lang="en">
    <meta charset="UTF-8">
    <title>Account activation</title>
</head>
<body>
<p>
    You're receiving this email because you created an account on Waldur.
</p>
<p>
    Please go to the following page to activate account: <a href="{{ activation_url }}">{{ activation_url }}</a>
</p>
<p>
    Thanks for using our site!
</p>
<p>
    The Waldur team.
</p>
</body>
</html>
